@@ -4,7 +4,7 @@
 | (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
 |                                                             |
 | Home page      : http://www-asim.lip6.fr/alliance/          |
-| E-mail support : mailto:alliance-support@asim.lip6.fr       |
+| E-mail         : mailto:alliance-users@asim.lip6.fr       |
 |                                                             |
 | This progam is  free software; you can redistribute it      |
 | and/or modify it under the  terms of the GNU Library General|
@@ -37,6 +37,10 @@
 # ifndef ABL_102_H
 # define ABL_102_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 # ifndef __P
 # if defined(__STDC__) ||  defined(__GNUC__)
 #  define __P(x) x
@@ -124,11 +128,15 @@
 
 # define ABL_CDR( E )        ( ( E )->NEXT )
 # define ABL_CAR( E )        ( (ablexpr *)( E )->DATA )
+# define ABL_CAR_L( E )      ( ( E )->DATA )
 # define ABL_CADR( E )       ( ABL_CAR( ABL_CDR( ( E ) ) ) )
+# define ABL_CADR_L( E )     ( ABL_CAR_L( ABL_CDR( ( E ) ) ) )
 # define ABL_CDDR( E )       ( ABL_CDR( ABL_CDR( ( E ) ) ) )
 # define ABL_ATOM( E )       ( ( E )->NEXT == (ablexpr *)0 )
 # define ABL_ATOM_VALUE( E ) ( (char *)( ( E )->DATA ) )
 # define ABL_OPER( E )       ( (long)( ( ABL_CAR( ( E ) ) )->DATA ) )
+# define ABL_OPER_L( E )     ( ( ABL_CAR( ( E ) ) )->DATA ) 
+# define SET_ABL_OPER( E,O ) ( ( ABL_CAR( (E) )->DATA = (void *)(O) ) )
 
 /*------------------------------------------------------\
 |                                                       |
@@ -386,4 +394,8 @@
   extern          char * viewablexprstr __P((ablexpr *Expr, int Mode));
   extern          char * viewablexprstrln __P((ablexpr *Expr, int Mode));
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 # endif
