@@ -30,16 +30,20 @@
 
 
 
-#ident "$Id: log_bdd0.c,v 1.3 2002/09/30 16:20:43 czo Exp $"
+#ident "$Id: log_bdd0.c,v 1.5 2006/03/29 17:10:13 xtof Exp $"
 
 /****************************************************************************/
 /*    Produit : librairie BDD - Gestion de BDD                              */
 /****************************************************************************/
 
 #include<stdio.h>
+#include<stdlib.h>
 #include "mut.h"
 #include "log.h"
 
+pNode one, zero;
+struct systemBdd sysBdd;
+
 #undef NAME_ATOM
 #undef MIN_OPER
 #undef MAX_OPER
