@@ -33,6 +33,7 @@
 #include <mlo.h>
 #include <abl.h>
 #include <abe.h>
+#include <aut.h>
 #include "lon_lax_param.h"
 #include "lon_signal_name.h"
 #include "lon_lib_matching.h"
@@ -60,7 +61,7 @@ static port_list* newport()
    int i;
 
    if (!PORT) {
-      PORT=mbkalloc(BLOCK*sizeof(port_list));
+      PORT=(port_list *)autallocblock(BLOCK*sizeof(port_list));
       new=PORT;
       for (i = 1; i < BLOCK; i++) {
          new->NEXT = new + 1;
@@ -120,7 +121,7 @@ extern void moveport(port_list* head, port_list* new)
    if (!head && !new) return;
    if (!head || !new) {
       fprintf(stderr,"moveport: discrepancy in length\n");
-      exit(1);
+      autexit(1);
    }
    
    moveport(head->NEXT,new->NEXT);
@@ -139,7 +140,7 @@ extern cell_list* copyCell(cell_list* old)
 {
    cell_list* cell;
 
-   cell=(cell_list*) mbkalloc(sizeof(cell_list));
+   cell=(cell_list*) autallocblock(sizeof(cell_list));
 
    cell->BEFIG=old->BEFIG;
    cell->NAME=old->NAME;
@@ -178,14 +179,14 @@ static lofig_list* build_lofig(lofig_list* lofig, chain_list* nameorder)
          if (locon->DIRECTION==UNKNOWN) {
             fprintf(stderr,"BEH: 'linkage %s' in figure '%s' isn't accepted\n",
             locon->NAME,lofig->NAME);
-            exit(1);
+            autexit(1);
          }
          if (locon->NAME==name) break;
       }
       if (!locon) {
          fprintf(stderr,"build_lofig: no locon '%s' found in '%s'\n",name,
          lofig->NAME);
-         exit(1);
+         autexit(1);
       }
       
       namechain=addchain(NULL,name);
@@ -215,7 +216,7 @@ static cell_list* properties_addCell(befig_list* befig, lofig_list *lofig)
    losig_list* losig;
 
 
-   cell=(cell_list*) mbkalloc(sizeof(cell_list));
+   cell=(cell_list*) autallocblock(sizeof(cell_list));
 
    cell->NAME=lofig->NAME;
    cell->AREA=getgenericarea(befig);
@@ -241,7 +242,7 @@ static cell_list* properties_addCell(befig_list* befig, lofig_list *lofig)
       if (!locon) {
          fprintf(stderr,"properties_addCell: locon '%s' not found\n",
          locon->NAME);
-         exit(1);
+         autexit(1);
       }
       losig=locon->SIG;
       
@@ -252,7 +253,7 @@ static cell_list* properties_addCell(befig_list* befig, lofig_list *lofig)
       if (!locon) {
          fprintf(stderr,"properties_addCell: locon '%s' not found in cell\n",
          locon->NAME);
-         exit(1);
+         autexit(1);
       }
       
       /*apply properties*/
@@ -317,7 +318,7 @@ extern cell_list* createCell(befig_list* befig)
    bepor_list* bepor;
 
 
-   cell=(cell_list*) mbkalloc(sizeof(cell_list));
+   cell=(cell_list*) autallocblock(sizeof(cell_list));
 
    cell->NAME=befig->NAME;
    cell->AREA=getgenericarea(befig);
@@ -357,8 +358,17 @@ extern void addCell(befig_list* befig)
    
    /*search same behaviour*/
    for (chain=CELLS; chain; chain=chain->NEXT) {
+      int x;
       cell= (cell_list*) chain->DATA;
-      if (compare_befig(cell->BEFIG,befig)) break;
+# if 0 /* LUDO: Remove verbose/debug message ? */
+printf("+ %s %s\n", cell->BEFIG->NAME, befig->NAME);
+# endif
+      x = compare_befig(cell->BEFIG,
+                        befig);
+# if 0 /* LUDO: Remove verbose/debug message ? */
+printf("- %s %s\n", cell->BEFIG->NAME, befig->NAME);
+# endif
+      if (x) break;
    }
    
    /*insert cell*/
@@ -397,7 +407,6 @@ extern cell_list* getCellbuffer()
    chain_list* chain;
    cell_list* cell, *best;
    befig_list* befig;
-
    for (chain=CELLS; chain; chain=chain->NEXT) {
       cell=(cell_list*) chain->DATA;
       befig=cell->BEFIG;
@@ -407,7 +416,7 @@ extern cell_list* getCellbuffer()
        && ABL_ATOM_VALUE(befig->BEOUT->ABL)!=getablatomzero() ) {
          best=cell;
          for (cell=cell->NEXT; cell; cell=cell->NEXT) {
-            if (best->AREA>cell->AREA) cell=best;
+            if (best->AREA>cell->AREA) best=cell;
          }
          return best;
       }  
