@@ -28,7 +28,7 @@
  * Modified by Czo <Olivier.Sirol@lip6.fr> 1997,98
  */
 
-#ident "$Id: mbk_util.c,v 1.3 2003/04/03 14:46:30 xtof Exp $"
+#ident "$Id: mbk_util.c,v 1.5 2003/10/20 10:04:39 xtof Exp $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -740,6 +740,20 @@ void upstr(const char *s, char *t)
    *t = *s;
 }
 
+/*******************************************************************************
+* function isck()                                                              *
+*******************************************************************************/
+int  isck(char *name)
+{
+    if (!name || !CK)
+        return 0;
+    else
+        if (!strcmp(name, CK))
+            return 1;
+        else
+            return 0;
+}
+
 /*******************************************************************************
 * function instr() : about strstr, but some systems don't have it              *
 *******************************************************************************/
