@@ -1,7 +1,7 @@
 
 // -*- C++ -*-
 //
-// $Id: MMBK.cpp,v 1.4 2002/10/24 07:51:33 hcl Exp $
+// $Id: MMBK.cpp,v 1.8 2005/10/17 23:11:05 jpc Exp $
 //
 // /-----------------------------------------------------------------\ 
 // |                                                                 |
@@ -48,11 +48,8 @@ namespace MBK {
 // -------------------------------------------------------------------
 // Constructor  :  "CXRect::CXRect()".
 
-CXRect::CXRect (long xab1, long yab1)
-{
-  XAB1 = xab1;
-  YAB1 = yab1;
-}
+CXRect::CXRect ( CDRGrid* agrid ) : drgrid(agrid)
+{ }
 
 
 
@@ -83,10 +80,9 @@ void  CXRect::setSeg (phseg_list &rSeg)
 
 void  CXRect::seg2rect (void)
 {
-  long  width;
-
-
-  width = env.layer2width (seg.LAYER);
+  long  width   = env.layer2width   (seg.LAYER);
+  long  spacing = env.layer2spacing (seg.LAYER);
+  long  expand;
 
   // Special case of "point like" segments.
   if ((seg.X1 == seg.X2) && (seg.Y1 == seg.Y2)) {
@@ -101,8 +97,12 @@ void  CXRect::seg2rect (void)
   switch (seg.TYPE) {
     case UP:
     case DOWN:
-      rect.x1 = seg.X1 - (seg.WIDTH - width) / 2;
-      rect.x2 = seg.X2 + (seg.WIDTH - width) / 2;
+      //rect.x1 = seg.X1 - (seg.WIDTH - width) / 2;
+      //rect.x2 = seg.X2 + (seg.WIDTH - width) / 2;
+      expand = (seg.WIDTH + spacing - env.grid_dy) / 2;
+      if ( expand < 0 ) expand = 0;
+      rect.x1 = seg.X1 - expand;
+      rect.x2 = seg.X2 + expand;
       rect.y1 = seg.Y1;
       rect.y2 = seg.Y2;
       break;
@@ -111,8 +111,12 @@ void  CXRect::seg2rect (void)
     default:
       rect.x1 = seg.X1;
       rect.x2 = seg.X2;
-      rect.y1 = seg.Y1 - (seg.WIDTH - width) / 2;
-      rect.y2 = seg.Y2 + (seg.WIDTH - width) / 2;
+      //rect.y1 = seg.Y1 - (seg.WIDTH - width) / 2;
+      //rect.y2 = seg.Y2 + (seg.WIDTH - width) / 2;
+      expand = (seg.WIDTH + spacing - env.grid_dx) / 2;
+      if ( expand < 0 ) expand = 0;
+      rect.y1 = seg.Y1 - expand;
+      rect.y2 = seg.Y2 + expand;
       break;
   }
 }
@@ -125,14 +129,37 @@ void  CXRect::seg2rect (void)
 
 void  CXRect::rect2grid (void)
 {
-  grid.x1 = (rect.x1 - XAB1) / env.grid_dx;
-  grid.y1 = (rect.y1 - YAB1) / env.grid_dy;
+  grid.x1 = (rect.x1 - drgrid->xoffset) / env.grid_dx;
+  grid.y1 = (rect.y1 - drgrid->yoffset) / env.grid_dy;
 
-  grid.x2 = (rect.x2 - XAB1) / env.grid_dx;
-  grid.y2 = (rect.y2 - YAB1) / env.grid_dy;
+  grid.x2 = (rect.x2 - drgrid->xoffset) / env.grid_dx;
+  grid.y2 = (rect.y2 - drgrid->yoffset) / env.grid_dy;
 
-  if (((rect.x2 - XAB1) % env.grid_dx) != 0) grid.x2 += 1;
-  if (((rect.y2 - XAB1) % env.grid_dy) != 0) grid.y2 += 1;
+  if (((rect.x2 - drgrid->xoffset) % env.grid_dx) != 0) grid.x2 += 1;
+  if (((rect.y2 - drgrid->yoffset) % env.grid_dy) != 0) grid.y2 += 1;
+
+  if (    (grid.x2 < 0) || (grid.x1 >= drgrid->X)
+       || (grid.y2 < 0) || (grid.y1 >= drgrid->Y) ) {
+    grid.x1 = -1;
+  } else {
+    if (grid.x1 < 0          ) grid.x1 = 0;
+    if (grid.y1 < 0          ) grid.y1 = 0;
+    if (grid.x2 > drgrid->X-1) grid.x2 = drgrid->X - 1;
+    if (grid.y2 > drgrid->Y-1) grid.y2 = drgrid->Y - 1;
+  }
+}
+
+
+
+
+// -------------------------------------------------------------------
+// Method  :  "CXRect::isInGrid()".
+
+bool  CXRect::isInGrid ()
+{
+  if (grid.x1 < 0) return false;
+
+  return true;
 }
 
 
@@ -147,7 +174,9 @@ ostream &operator<< (ostream &o, const CXRect *rect)
     << rect->seg.X1 << ", "
     << rect->seg.Y1 << "), ("
     << rect->seg.X2 << ", "
-    << rect->seg.Y2 << ")\n";
+    << rect->seg.Y2 << ") "
+    << rect->seg.WIDTH << " "
+    << layer2a(rect->seg.LAYER) << "\n";
 
   o << "+         CXRect::rect(" << &(rect->rect) << ")\n";
   o << "+         CXRect::grid(" << &(rect->grid) << ")\n";
@@ -168,18 +197,25 @@ CEnv::CEnv (void)
 
   // Copy constants values from constants namespace ("D::").
   // Routing constants, loaded now that we have SCALE_X.
-  D::X_GRID            = ::MBK::SCALE (D::_X_GRID);
-  D::Y_GRID            = ::MBK::SCALE (D::_Y_GRID);
-  D::WIDTH_VSS         = ::MBK::SCALE (D::_WIDTH_VSS);
-  D::WIDTH_VDD         = ::MBK::SCALE (D::_WIDTH_VDD);
-  D::Y_SLICE           = ::MBK::SCALE (D::_Y_SLICE);
-  D::TRACK_WIDTH_ALU1  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU1);
-  D::TRACK_WIDTH_ALU2  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU2);
-  D::TRACK_WIDTH_ALU3  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU3);
-  D::TRACK_WIDTH_ALU4  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU4);
-  D::TRACK_WIDTH_ALU5  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU5);
-  D::TRACK_WIDTH_ALU6  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU6);
-  D::TRACK_WIDTH_ALU7  = ::MBK::SCALE (D::_TRACK_WIDTH_ALU7);
+  D::X_GRID             = ::MBK::SCALE (D::_X_GRID);
+  D::Y_GRID             = ::MBK::SCALE (D::_Y_GRID);
+  D::WIDTH_VSS          = ::MBK::SCALE (D::_WIDTH_VSS);
+  D::WIDTH_VDD          = ::MBK::SCALE (D::_WIDTH_VDD);
+  D::Y_SLICE            = ::MBK::SCALE (D::_Y_SLICE);
+  D::TRACK_WIDTH_ALU1   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU1);
+  D::TRACK_WIDTH_ALU2   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU2);
+  D::TRACK_WIDTH_ALU3   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU3);
+  D::TRACK_WIDTH_ALU4   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU4);
+  D::TRACK_WIDTH_ALU5   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU5);
+  D::TRACK_WIDTH_ALU6   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU6);
+  D::TRACK_WIDTH_ALU7   = ::MBK::SCALE (D::_TRACK_WIDTH_ALU7);
+  D::TRACK_SPACING_ALU1 = ::MBK::SCALE (D::_TRACK_SPACING_ALU1);
+  D::TRACK_SPACING_ALU2 = ::MBK::SCALE (D::_TRACK_SPACING_ALU2);
+  D::TRACK_SPACING_ALU3 = ::MBK::SCALE (D::_TRACK_SPACING_ALU3);
+  D::TRACK_SPACING_ALU4 = ::MBK::SCALE (D::_TRACK_SPACING_ALU4);
+  D::TRACK_SPACING_ALU5 = ::MBK::SCALE (D::_TRACK_SPACING_ALU5);
+  D::TRACK_SPACING_ALU6 = ::MBK::SCALE (D::_TRACK_SPACING_ALU6);
+  D::TRACK_SPACING_ALU7 = ::MBK::SCALE (D::_TRACK_SPACING_ALU7);
 
   // Grid spacing.
   grid_dx = D::X_GRID;
@@ -208,6 +244,29 @@ CEnv::CEnv (void)
   ALU2W[TALU6] = D::TRACK_WIDTH_ALU6;
   ALU2W[TALU7] = D::TRACK_WIDTH_ALU7;
 
+  // Layers minimal width.
+  ALU2S[ALU1]  = D::TRACK_SPACING_ALU1;
+  ALU2S[ALU2]  = D::TRACK_SPACING_ALU2;
+  ALU2S[ALU3]  = D::TRACK_SPACING_ALU3;
+  ALU2S[ALU4]  = D::TRACK_SPACING_ALU4;
+  ALU2S[ALU5]  = D::TRACK_SPACING_ALU5;
+  ALU2S[ALU6]  = D::TRACK_SPACING_ALU6;
+  ALU2S[ALU7]  = D::TRACK_SPACING_ALU7;
+  ALU2S[CALU1] = D::TRACK_SPACING_ALU1;
+  ALU2S[CALU2] = D::TRACK_SPACING_ALU2;
+  ALU2S[CALU3] = D::TRACK_SPACING_ALU3;
+  ALU2S[CALU4] = D::TRACK_SPACING_ALU4;
+  ALU2S[CALU5] = D::TRACK_SPACING_ALU5;
+  ALU2S[CALU6] = D::TRACK_SPACING_ALU6;
+  ALU2S[CALU7] = D::TRACK_SPACING_ALU7;
+  ALU2S[TALU1] = D::TRACK_SPACING_ALU1;
+  ALU2S[TALU2] = D::TRACK_SPACING_ALU2;
+  ALU2S[TALU3] = D::TRACK_SPACING_ALU3;
+  ALU2S[TALU4] = D::TRACK_SPACING_ALU4;
+  ALU2S[TALU5] = D::TRACK_SPACING_ALU5;
+  ALU2S[TALU6] = D::TRACK_SPACING_ALU6;
+  ALU2S[TALU7] = D::TRACK_SPACING_ALU7;
+
   // Layer to Z translation table.
   ALU2Z[ALU1]  = 0;
   ALU2Z[ALU2]  = 1;
@@ -230,6 +289,8 @@ CEnv::CEnv (void)
   ALU2Z[TALU5] = 4;
   ALU2Z[TALU6] = 5;
   ALU2Z[TALU7] = 6;
+
+  regcomp(&pxLibRegex,"p.*px",REG_EXTENDED|REG_NOSUB);
 }
 
 
@@ -255,6 +316,26 @@ long  CEnv::layer2width (char layer) throw (except_done)
 
 
 
+// -------------------------------------------------------------------
+// Method  :  "CEnv::layer2spacing()".
+
+long  CEnv::layer2spacing (char layer) throw (except_done)
+{
+  MLayer::iterator  itLayer;
+
+
+  if ((itLayer = ALU2S.find (layer)) == ALU2S.end ()) {
+    cerr << herr ("CEnv::layer2spacing ():\n");
+    cerr << "  Layer id " << (int)layer << " is not supported.\n";
+    throw except_done ();
+  }
+    
+  return (itLayer->second);
+}
+
+
+
+
 // -------------------------------------------------------------------
 // Method  :  "CEnv::layer2z()".
 
@@ -538,15 +619,15 @@ void CPhfig::rflatten (char concat, char catal)
 // -------------------------------------------------------------------
 // Method :  "CPhfig::onslice()".
 
-bool CPhfig::onslice (long Y)
+bool CPhfig::onslice (long Y, long yoff)
 {
   if (Y < fig->YAB1) return (false);
   if (Y > fig->YAB2) return (false);
 
-  if (!(((Y - D::WIDTH_VDD / 2) - fig->YAB1) % D::Y_SLICE)) return (true);
-  if (!(((Y + D::WIDTH_VDD / 2) - fig->YAB1) % D::Y_SLICE)) return (true);
-  if (!(((Y - D::WIDTH_VSS / 2) - fig->YAB1) % D::Y_SLICE)) return (true);
-  if (!(((Y + D::WIDTH_VSS / 2) - fig->YAB1) % D::Y_SLICE)) return (true);
+  if (!(((Y - D::WIDTH_VDD / 2) - yoff ) % D::Y_SLICE)) return (true);
+  if (!(((Y + D::WIDTH_VDD / 2) - yoff ) % D::Y_SLICE)) return (true);
+  if (!(((Y - D::WIDTH_VSS / 2) - yoff ) % D::Y_SLICE)) return (true);
+  if (!(((Y + D::WIDTH_VSS / 2) - yoff ) % D::Y_SLICE)) return (true);
 
   return (false);
 }
@@ -770,17 +851,31 @@ CFig::~CFig (void)
 // -------------------------------------------------------------------
 // Method :  "CFig::addphseg()".
 
-void  CFig::addphseg (phseg_list &seg)
+void  CFig::addphseg (phseg_list &seg, bool isTerm, bool isChip )
 {
-  MBK::addphseg ( phfig.fig
-                , seg.LAYER
-                , seg.WIDTH
-                , seg.X1
-                , seg.Y1
-                , seg.X2
-                , seg.Y2
-                , seg.NAME
-                );
+  if ( !isChip || !isobs(seg.LAYER) ) {
+    MBK::addphseg ( phfig.fig
+                  , seg.LAYER
+                  , seg.WIDTH
+                  , seg.X1
+                  , seg.Y1
+                  , seg.X2
+                  , seg.Y2
+                  , seg.NAME
+                  );
+  }
+
+  if ( !isTerm && !isChip ) {
+    MBK::addphseg ( phfig.fig
+                  , layer2TALU(seg.LAYER)
+                  , seg.WIDTH
+                  , seg.X1
+                  , seg.Y1
+                  , seg.X2
+                  , seg.Y2
+                  , "obs"
+                  );
+  }
 }
 
 
@@ -816,6 +911,20 @@ void  CFig::addphcon (phcon_list &con)
 }
 
 
+// -------------------------------------------------------------------
+// Method :  "CFig::addphref()".
+
+void  CFig::addphref (phref_list &ref)
+{
+  MBK::addphref ( phfig.fig
+                , ref.FIGNAME
+                , ref.NAME
+                , ref.XREF
+                , ref.YREF
+                );
+}
+
+
 
 
 // -------------------------------------------------------------------
@@ -824,6 +933,8 @@ void  CFig::addphcon (phcon_list &con)
 extern char *layer2a(char layer)
 {
   switch (layer) {
+    case NDIF:  return ("NDIF");
+    case PDIF:  return ("PDIF");
     case ALU1:  return ("ALU1");
     case ALU2:  return ("ALU2");
     case ALU3:  return ("ALU3");
@@ -928,6 +1039,48 @@ bool  isCALU (char layer)
 
 
 
+// -------------------------------------------------------------------
+// Function  :  "layer2TALU()".
+
+char  layer2TALU (char layer)
+{
+  switch (layer) {
+    case  ALU1:
+    case TALU1:
+      return (TALU1);
+    case  ALU2:
+    case TALU2:
+      return (TALU2);
+    case  ALU3:
+    case TALU3:
+      return (TALU3);
+    case  ALU4:
+    case TALU4:
+      return (TALU4);
+    case  ALU5:
+    case TALU5:
+      return (TALU5);
+    case  ALU6:
+    case TALU6:
+      return (TALU6);
+    case TALU7:
+    case  ALU7:
+      return (TALU7);
+    case TALU8:
+    case  ALU8:
+      return (TALU8);
+    case TALU9:
+    case  ALU9:
+      return (TALU9);
+  }
+
+  return (TALU1);
+}
+
+
+
+
+
 // -------------------------------------------------------------------
 // Function  :  "layer2CALU()".
 
@@ -1112,13 +1265,20 @@ long  cmpALU (char layer1, char layer2)
 char  topVIALayer (char type)
 {
   switch (type) {
-    case CONT_VIA:  return (ALU1); break;
-    case CONT_VIA2: return (ALU2); break;
-    case CONT_VIA3: return (ALU3); break;
-    case CONT_VIA4: return (ALU4); break;
-    case CONT_VIA5: return (ALU5); break;
-    case CONT_VIA6: return (ALU6); break;
-    case CONT_VIA7: return (ALU7); break;
+    case CONT_VIA:   return (ALU1); break;
+    case CONT_VIA2:  return (ALU2); break;
+    case CONT_VIA3:  return (ALU3); break;
+    case CONT_VIA4:  return (ALU4); break;
+    case CONT_VIA5:  return (ALU5); break;
+    case CONT_VIA6:  return (ALU6); break;
+    case CONT_VIA7:  return (ALU7); break;
+    case CONT_TURN1: return (ALU1); break;
+    case CONT_TURN2: return (ALU2); break;
+    case CONT_TURN3: return (ALU3); break;
+    case CONT_TURN4: return (ALU4); break;
+    case CONT_TURN5: return (ALU5); break;
+    case CONT_TURN6: return (ALU6); break;
+    case CONT_TURN7: return (ALU7); break;
   }
 
   return (ALU8);
@@ -1134,13 +1294,20 @@ char  topVIALayer (char type)
 char  bottomVIALayer (char type)
 {
   switch (type) {
-    case CONT_VIA:  return (ALU2); break;
-    case CONT_VIA2: return (ALU3); break;
-    case CONT_VIA3: return (ALU4); break;
-    case CONT_VIA4: return (ALU5); break;
-    case CONT_VIA5: return (ALU6); break;
-    case CONT_VIA6: return (ALU7); break;
-    case CONT_VIA7: return (ALU8); break;
+    case CONT_VIA:   return (ALU2); break;
+    case CONT_VIA2:  return (ALU3); break;
+    case CONT_VIA3:  return (ALU4); break;
+    case CONT_VIA4:  return (ALU5); break;
+    case CONT_VIA5:  return (ALU6); break;
+    case CONT_VIA6:  return (ALU7); break;
+    case CONT_VIA7:  return (ALU8); break;
+    case CONT_TURN1: return (ALU1); break;
+    case CONT_TURN2: return (ALU2); break;
+    case CONT_TURN3: return (ALU3); break;
+    case CONT_TURN4: return (ALU4); break;
+    case CONT_TURN5: return (ALU5); break;
+    case CONT_TURN6: return (ALU6); break;
+    case CONT_TURN7: return (ALU7); break;
   }
 
   return (ALU9);
@@ -1149,6 +1316,17 @@ char  bottomVIALayer (char type)
 
 
 
+// -------------------------------------------------------------------
+// Function  :  "isPxLib()".
+
+bool  IsPxLib ( phfig_list* model )
+{
+  return regexec(&env.pxLibRegex,model->NAME,0,NULL,0) == 0;
+}
+
+
+
+
 // -------------------------------------------------------------------
 // End of MBK namespace.
 
