@@ -1,17 +1,58 @@
-#include "PPlacement.h"
+
+// This file is part of the Alliance Project.
+// Copyright (C) Laboratoire LIP6 - Departement ASIM
+// Universite Pierre et Marie Curie
+//
+// The Alliance Project  is free software;  you can  redistribute it and/or
+// modify  it  under the  terms  of  the  GNU  General  Public License  as
+// published by  the Free  Software Foundation; either  version 2  of  the
+// License, or (at your option) any later version.
+// 
+// The Alliance Project  is distributed in the hope that it will be useful,
+// but  WITHOUT  ANY  WARRANTY;  without  even  the  implied  warranty  of
+// MERCHANTABILITY  or  FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+// General Public License for more details.
+// 
+// You should have received a copy  of  the  GNU  General  Public  License
+// along with  the Alliance Project;  if  not,  write to the  Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+//
+// License-Tag
+//
+// Date   : 29/01/2004
+// Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
+//
+// Authors-Tag 
+#ifdef __GNUC__
+#if __GNUC__ < 3
+#include <hash_map.h>
+#else
+#include <ext/hash_map>
+#if __GNUC_MINOR__ == 0
+#else
+using namespace __gnu_cxx; // GCC 3.1 and later
+#endif
+#endif
+#endif
+
 #include <math.h>
 #include <unistd.h>
 #include <algorithm>
-#include <hash_map.h>
-#include "PMove.h"
-#include "PConstants.h"
-#include "PDetPlacement.h"
+using namespace std;
+
 #include "mut.h"
 #include "mph.h"
 #include "mpu.h"
 #include "mlo.h"
 #include "mlu.h"
 
+#include "PMove.h"
+#include "PConstants.h"
+#include "PDetPlacement.h"
+
+#include "PPlacement.h"
+
 double
 PPlacement::DetPlaceDebugNetCost()
 {
@@ -132,7 +173,11 @@ PPlacement::FinalInitialize()
 		eit != (*nit)->GetElems().end();
 		eit++)
 	{
-	    assert(!dynamic_cast<PToPlaceIns*>(*eit));
+            if (dynamic_cast<PToPlaceIns*>(*eit))
+            {
+                cerr << " o INTERNAL ERROR: FinalInitialize" << endl;
+                exit(1);
+            }
 	}
     }
     // on efface ce qui ne nous sert plus.
@@ -248,6 +293,9 @@ PPlacement::Save()
 
     for (PCons::const_iterator cit = _cons.begin(); cit != _cons.end(); cit++)
     {
+       if (_ringPlaceCons)
+    	(*cit)->RingSave(physicalfig, _dx, _dy);
+       else
     	(*cit)->Save(physicalfig, _dx, _dy);
     }
     
