@@ -1194,13 +1194,13 @@ int pat_decl_y_parse ();
 
 
 /* The lookahead symbol.  */
-int pat_decl_y_char;
+extern int pat_decl_y_char;
 
 /* The semantic value of the lookahead symbol.  */
-PAT_DECL_Y_STYPE pat_decl_y_lval;
+extern PAT_DECL_Y_STYPE pat_decl_y_lval;
 
 /* Number of syntax errors so far.  */
-int pat_decl_y_nerrs;
+extern int pat_decl_y_nerrs;
 
 
 
