@@ -44,6 +44,8 @@
 \------------------------------------------------------------*/
 
 # include <stdio.h>
+# include <stdlib.h>
+# include <string.h>
 # include <Xm/Xm.h>
  
 # include "mut.h"
